@@ -56,17 +56,19 @@ class Frequency(IntEnum):
     The different frequencies that data can occur.
     """
     NONE = 0
-    FIVE_MINUTES = 1
-    FIFTEEN_MINUTES = 2
-    THIRTY_MINUTES = 3
-    HOURLY = 4
-    DAILY = 5
-    WEEKLY = 6
-    MONTHLY = 7
-    QUARTERLY = 8
-    ANNUAL = 9
-    BIANNUAL = 10
-    IRREGULAR = 11
+    ONE_MINUTE = 1
+    FIVE_MINUTES = 2
+    TEN_MINUTES = 3
+    FIFTEEN_MINUTES = 4
+    THIRTY_MINUTES = 5
+    HOURLY = 6
+    DAILY = 7
+    WEEKLY = 8
+    MONTHLY = 8
+    QUARTERLY = 10
+    ANNUAL = 11
+    BIANNUAL = 12
+    IRREGULAR = 13
 
 
 def is_valid_token(token: str or None) -> bool:
@@ -571,10 +573,10 @@ class DataId:
                     return False
 
             if self._code is None:
-                if other.code is None:
+                if other.category is None:
                     return False
             else:
-                if self._code != other.code:
+                if self._code != other.category:
                     return False
 
             if self._id is None:
