@@ -29,8 +29,8 @@ class CollectionMetadata:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 cid: str,
+                 category: str,
+                 label: str,
                  url: str,
                  summary: str,
                  description: str,
@@ -46,11 +46,11 @@ class CollectionMetadata:
         :param source: The source for the collection.
         :type source: str
 
-        :param code: The code for the collection.
-        :type code: str
+        :param category: The category for the collection.
+        :type category: str
 
-        :param cid: The ID for the collection.
-        :type cid: str
+        :param label: The label for the collection.
+        :type label: str
 
         :param url: The URL for the collection..
         :type url: str
@@ -87,17 +87,17 @@ class CollectionMetadata:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(cid, str):
-            raise ValueError("cid is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("cid is not valid")
+        if not is_valid_token(category):
+            raise ValueError("label is not valid")
 
         if not isinstance(url, str):
             raise ValueError("url is not a valid str")
@@ -152,8 +152,8 @@ class CollectionMetadata:
         # Store the data
 
         self._source = source
-        self._code = code
-        self._cid = cid
+        self._category = category
+        self._label = label
         self._url = url
         self._summary = summary
         self._description = description
@@ -170,13 +170,12 @@ class CollectionMetadata:
         """
         Calculates and caches the hash code associated with this.
         """
-
         prime = 31
         result = 1
 
         result = prime * result + hash(self._source) if self._source is not None else 0
-        result = prime * result + hash(self._code) if self._code is not None else 0
-        result = prime * result + hash(self._cid) if self._cid is not None else 0
+        result = prime * result + hash(self._category) if self._category is not None else 0
+        result = prime * result + hash(self._label) if self._label is not None else 0
 
         self._hash_code = result
 
@@ -191,24 +190,24 @@ class CollectionMetadata:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the collection.
+        Returns the category for the collection.
 
-        :return: The code for the collection.
+        :return: The category for the collection.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def cid(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the collection.
+        Returns the label for the collection.
 
-        :return: The ID for the collection.
+        :return: The label for the collection.
         :rtype: str
         """
-        return self._cid
+        return self._label
 
     @property
     def url(self) -> str:
@@ -335,8 +334,8 @@ class CollectionMetadata:
         :type metadata: CollectionMetadata_pb2.CollectionMetadata
         """
         self._source = metadata.source
-        self._code = metadata.code
-        self._cid = metadata.id
+        self._category = metadata.category
+        self._label = metadata.label
         self._url = metadata.url
         self._summary = metadata.summary
         self._description = metadata.description
@@ -373,8 +372,8 @@ class CollectionMetadata:
         """
         metadata = CollectionMetadata_pb2.CollectionMetadata()
         metadata.source = self._source
-        metadata.code = self._code
-        metadata.id = self._cid
+        metadata.category = self._category
+        metadata.label = self._label
         metadata.url = self._url
         metadata.summary = self._summary
         metadata.description = self._description
@@ -425,14 +424,14 @@ class CollectionMetadata:
             elif self._source != other._source:
                 return False
 
-            if self._code is None and other._code is not None:
+            if self._category is None and other._category is not None:
                 return False
-            elif self._code != other._code:
+            elif self._category != other._category:
                 return False
 
-            if self._cid is None and other._cid is not None:
+            if self._label is None and other._label is not None:
                 return False
-            elif self._cid != other._cid:
+            elif self._label != other._label:
                 return False
 
             return True
@@ -444,8 +443,8 @@ class CollectionMetadata:
 
     def __str__(self):
         return "Source = " + self._source + \
-               "Code = " + self._code + \
-               "ID = " + self._cid + \
+               "Category = " + self._category + \
+               "Label = " + self._label + \
                "URL = " + self._url + \
                "Summary = " + self._summary + \
                "Description = " + self._description + \
@@ -787,8 +786,8 @@ class CollectionMetadataRequest:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 cid: str,
+                 category: str,
+                 label: str,
                  api_key: str = None):
         """
         All parameters should be supplied unless deserializing an object.
@@ -796,11 +795,11 @@ class CollectionMetadataRequest:
         :param source: The source for the collection.
         :type :source str
 
-        :param code: The code for the collection.
-        :type code: str
+        :param category: The category for the collection.
+        :type category: str
 
-        :param cid: The ID for the collection.
-        :type cid: str
+        :param label: The label for the collection.
+        :type label: str
 
         :param api_key: The API Key.
         :type api_key: str or None
@@ -819,24 +818,24 @@ class CollectionMetadataRequest:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(cid, str):
-            raise ValueError("cid is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(cid):
-            raise ValueError("cid is not valid")
+        if not is_valid_token(label):
+            raise ValueError("label is not valid")
 
         # Store the data
 
         self._api_key = api_key
         self._source = source
-        self._code = code
-        self._cid = cid
+        self._category = category
+        self._label = label
         self._client_type = ClientType.PYTHON_CLIENT
 
     @property
@@ -877,24 +876,24 @@ class CollectionMetadataRequest:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the collection.
+        Returns the category for the collection.
 
-        :return: The code for the collection.
+        :return: The category for the collection.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def cid(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the collection.
+        Returns the label for the collection.
 
-        :return: The ID for the collection.
+        :return: The label for the collection.
         :rtype: str
         """
-        return self._cid
+        return self._label
 
     @property
     def client_type(self) -> str:
@@ -944,8 +943,8 @@ class CollectionMetadataRequest:
         """
         self._api_key = metadata_request.apiKey
         self._source = metadata_request.source
-        self._code = metadata_request.code
-        self._cid = metadata_request.id
+        self._category = metadata_request.category
+        self._label = metadata_request.label
         self._client_type = metadata_request.clientType
 
     def _write_proto_object(self) -> CollectionMetadataRequest_pb2.CollectionMetadataRequest:
@@ -958,8 +957,8 @@ class CollectionMetadataRequest:
         request = CollectionMetadataRequest_pb2.CollectionMetadataRequest()
         request.apiKey = self._api_key
         request.source = self._source
-        request.code = self._code
-        request.id = self._cid
+        request.category = self._category
+        request.label = self._label
         request.clientType = self._client_type
 
         return request
@@ -1144,8 +1143,8 @@ class CollectionRequest:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 cid: str,
+                 category: str,
+                 label: str,
                  features: List[str] = None,
                  max_size: int = -1,
                  filters: Dict[str, str] = None,
@@ -1154,11 +1153,11 @@ class CollectionRequest:
         :param source: The source for the collection.
         :type source: str
 
-        :param code: The code for the collection.
-        :type code: str
+        :param category: The category for the collection.
+        :type category: str
 
-        :param cid: The ID for the collection.
-        :type cid: str
+        :param label: The label for the collection.
+        :type label: str
 
         :param features: The (optional) list of features, or None.
         :type features: List[str]
@@ -1186,17 +1185,17 @@ class CollectionRequest:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(cid, str):
-            raise ValueError("cid is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(cid):
-            raise ValueError("cid is not valid")
+        if not is_valid_token(label):
+            raise ValueError("label is not valid")
 
         if features is not None:
             if not isinstance(features, list):
@@ -1234,8 +1233,8 @@ class CollectionRequest:
 
         self._api_key = api_key
         self._source = source
-        self._code = code
-        self._cid = cid
+        self._category = category
+        self._label = label
         self._features = features
         self._max_size = max_size
         self._filters = filters
@@ -1275,24 +1274,24 @@ class CollectionRequest:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the collection.
+        Returns the category for the collection.
 
-        :return: The code for the collection.
+        :return: The category for the collection.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def cid(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the collection.
+        Returns the label for the collection.
 
-        :return: The ID for the collection.
+        :return: The label for the collection.
         :rtype: str
         """
-        return self._cid
+        return self._label
 
     @property
     def features(self) -> List[str] or None:
@@ -1372,8 +1371,8 @@ class CollectionRequest:
         """
         self._api_key = request.apiKey
         self._source = request.source
-        self._code = request.code
-        self._cid = request.id
+        self._category = request.category
+        self._label = request.label
 
         if request.featuresSet:
             self._features = request.features
@@ -1394,8 +1393,8 @@ class CollectionRequest:
         request = CollectionRequest_pb2.CollectionRequest()
         request.apiKey = self._api_key
         request.source = self._source
-        request.code = self._code
-        request.id = self._cid
+        request.category = self._category
+        request.label = self._label
 
         if self._features is not None:
             request.featuresSet = True
