@@ -2,7 +2,6 @@
 Contains classes and functions related to file stores.
 """
 from __future__ import annotations
-from typing import List, Dict
 
 from archipelagos.common.data import get_secs_from_timestamp, get_nanos_from_timestamp, get_timestamp
 from archipelagos.common.data import get_yyyy_mm_dd_hh_mm_ss_n
@@ -14,11 +13,11 @@ from archipelagos.common.protobuf.common.data.filestore import FileMetadataReque
 from archipelagos.common.protobuf.common.data.filestore import FileStoreMetadata_pb2, FileMetadata_pb2
 from archipelagos.common.protobuf.common import Timestamp_pb2
 from archipelagos.common.platform import ClientType
-
 from archipelagos.common.data import is_valid_token
 
-import array
 from pandas import Timestamp
+from typing import List, Dict
+import array
 
 
 class FileStoreMetadata:
@@ -27,8 +26,8 @@ class FileStoreMetadata:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 fs_id: str,
+                 category: str,
+                 label: str,
                  url: str,
                  summary: str,
                  description: str,
@@ -42,11 +41,11 @@ class FileStoreMetadata:
         :param source: The source for the file store.
         :type source: str
 
-        :param code: The code for the file store.
-        :type code: str
+        :param category: The category for the file store.
+        :type category: str
 
-        :param fs_id: The ID for the file store.
-        :type fs_id: str
+        :param label: The label for the file store.
+        :type label: str
 
         :param url: The URL for the file store.
         :type url: str
@@ -77,17 +76,17 @@ class FileStoreMetadata:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(fs_id, str):
-            raise ValueError("fs_id is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(fs_id):
-            raise ValueError("fs_id is not valid")
+        if not is_valid_token(label):
+            raise ValueError("label is not valid")
 
         if not isinstance(url, str):
             raise ValueError("url is not a valid str")
@@ -128,8 +127,8 @@ class FileStoreMetadata:
         # Store the data
 
         self._source = source
-        self._code = code
-        self._fs_id = fs_id
+        self._category = category
+        self._label = label
         self._url = url
         self._summary = summary
         self._description = description
@@ -148,8 +147,8 @@ class FileStoreMetadata:
         result = 1
 
         result = prime * result + hash(self._source) if self._source is not None else 0
-        result = prime * result + hash(self._code) if self._code is not None else 0
-        result = prime * result + hash(self._fs_id) if self._fs_id is not None else 0
+        result = prime * result + hash(self._category) if self._category is not None else 0
+        result = prime * result + hash(self._label) if self._label is not None else 0
 
         self._hash_code = result
 
@@ -164,24 +163,24 @@ class FileStoreMetadata:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the file store.
+        Returns the category for the file store.
 
-        :return: The code for the file store.
+        :return: The category for the file store.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def fs_id(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the file store.
+        Returns the label for the file store.
 
-        :return: The ID for the file store.
+        :return: The label for the file store.
         :rtype: str
         """
-        return self._fs_id
+        return self._label
 
     @property
     def url(self) -> str:
@@ -288,8 +287,8 @@ class FileStoreMetadata:
         :type metadata: FileStoreMetadata_pb2.FileStoreMetadata
         """
         self._source = metadata.source
-        self._code = metadata.code
-        self._fs_id = metadata.id
+        self._category = metadata.category
+        self._label = metadata.label
         self._url = metadata.url
         self._summary = metadata.summary
         self._description = metadata.description
@@ -312,8 +311,8 @@ class FileStoreMetadata:
         """
         metadata = FileStoreMetadata_pb2.FileStoreMetadata()
         metadata.source = self._source
-        metadata.code = self._code
-        metadata.id = self._fs_id
+        metadata.category = self._category
+        metadata.label = self._label
         metadata.url = self._url
         metadata.summary = self._summary
         metadata.description = self._description
@@ -348,14 +347,14 @@ class FileStoreMetadata:
             elif self._source != other._source:
                 return False
 
-            if self._code is None and other._code is not None:
+            if self._category is None and other._category is not None:
                 return False
-            elif self._code != other._code:
+            elif self._category != other._category:
                 return False
 
-            if self._fs_id is None and other._fs_id is not None:
+            if self._label is None and other._label is not None:
                 return False
-            elif self._fs_id != other._fs_id:
+            elif self._label != other._label:
                 return False
 
             return True
@@ -367,8 +366,8 @@ class FileStoreMetadata:
 
     def __str__(self):
         return "Source = " + self._source + \
-               "Code = " + self._code + \
-               "ID = " + self._fs_id + \
+               "Category = " + self._category + \
+               "Label = " + self._label + \
                "URL = " + self._url + \
                "Summary = " + self._summary + \
                "Description = " + self._description + \
@@ -383,8 +382,8 @@ class FileMetadata:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 fs_id: str,
+                 category: str,
+                 label: str,
                  name: str,
                  size: int,
                  premium: bool,
@@ -395,11 +394,11 @@ class FileMetadata:
         :param source: The source for the file store.
         :type source: str
 
-        :param code: The code for the file store.
-        :type code: str
+        :param category: The category for the file store.
+        :type category: str
 
-        :param fs_id: The ID for the file store.
-        :type fs_id: str
+        :param label: The label for the file store.
+        :type label: str
 
         :param name: The name of the file.
         :type name: str
@@ -421,17 +420,17 @@ class FileMetadata:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(fs_id, str):
-            raise ValueError("fs_id is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(fs_id):
-            raise ValueError("fs_id is not valid")
+        if not is_valid_token(label):
+            raise ValueError("label is not valid")
 
         if not isinstance(name, str):
             raise ValueError("name is not a valid str")
@@ -448,8 +447,8 @@ class FileMetadata:
         # Store the data
 
         self._source = source
-        self._code = code
-        self._fs_id = fs_id
+        self._category = category
+        self._label = label
         self._name = name
         self._size = size
         self._premium = premium
@@ -466,8 +465,8 @@ class FileMetadata:
         result = 1
 
         result = prime * result + hash(self._source) if self._source is not None else 0
-        result = prime * result + hash(self._code) if self._code is not None else 0
-        result = prime * result + hash(self._fs_id) if self._fs_id is not None else 0
+        result = prime * result + hash(self._category) if self._category is not None else 0
+        result = prime * result + hash(self._label) if self._label is not None else 0
         result = prime * result + hash(self._name) if self._name is not None else 0
 
         self._hash_code = result
@@ -483,24 +482,24 @@ class FileMetadata:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the file store.
+        Returns the category for the file store.
 
-        :return: The code for the file store.
+        :return: The category for the file store.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def fs_id(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the file store.
+        Returns the label for the file store.
 
-        :return: The ID for the file store.
+        :return: The label for the file store.
         :rtype: str
         """
-        return self._fs_id
+        return self._label
 
     @property
     def name(self) -> str:
@@ -578,8 +577,8 @@ class FileMetadata:
         :type metadata: FileMetadata_pb2.FileMetadata
         """
         self._source = metadata.source
-        self._code = metadata.code
-        self._fs_id = metadata.id
+        self._category = metadata.category
+        self._label = metadata.label
         self._name = metadata.name
         self._size = metadata.size
         self._premium = metadata.premium
@@ -598,8 +597,8 @@ class FileMetadata:
         """
         metadata = FileMetadata_pb2.FileMetadata()
         metadata.source = self._source
-        metadata.code = self._code
-        metadata.id = self._fs_id
+        metadata.category = self._category
+        metadata.label = self._label
         metadata.name = self._name
         metadata.size = self._size
         metadata.premium = self._premium
@@ -628,14 +627,14 @@ class FileMetadata:
             elif self._source != other._source:
                 return False
 
-            if self._code is None and other._code is not None:
+            if self._category is None and other._category is not None:
                 return False
-            elif self._code != other._code:
+            elif self._category != other._category:
                 return False
 
-            if self._fs_id is None and other._fs_id is not None:
+            if self._label is None and other._label is not None:
                 return False
-            elif self._fs_id != other._fs_id:
+            elif self._label != other._label:
                 return False
 
             if self._name is None and other._name is not None:
@@ -652,8 +651,8 @@ class FileMetadata:
 
     def __str__(self):
         return "Source = " + self._source + \
-               "Code = " + self._code + \
-               "ID = " + self._fs_id + \
+               "Category = " + self._category + \
+               "Label = " + self._label + \
                "Name = " + self._name + \
                "Size = " + str(self._size) + \
                "Premium = " + str(self._premium) + \
@@ -666,8 +665,8 @@ class FileStoreMetadataRequest:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 fs_id: str,
+                 category: str,
+                 label: str,
                  api_key: str = None):
         """
         All parameters should be supplied unless deserializing an object.
@@ -675,11 +674,11 @@ class FileStoreMetadataRequest:
         :param source: The source for the file store.
         :type source: str
 
-        :param code: The code for the file store.
-        :type code: str
+        :param category: The category for the file store.
+        :type category: str
 
-        :param fs_id: The ID for the file store.
-        :type fs_id: str
+        :param label: The label for the file store.
+        :type label: str
 
         :param api_key: The API Key.
         :type api_key: str
@@ -698,24 +697,24 @@ class FileStoreMetadataRequest:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(fs_id, str):
-            raise ValueError("fs_id is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(fs_id):
-            raise ValueError("fs_id is not valid")
+        if not is_valid_token(label):
+            raise ValueError("label is not valid")
 
         # Store the data
 
         self._api_key = api_key
         self._source = source
-        self._code = code
-        self._fs_id = fs_id
+        self._category = category
+        self._label = label
         self._client_type = ClientType.PYTHON_CLIENT
 
     @property
@@ -756,24 +755,24 @@ class FileStoreMetadataRequest:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the file store.
+        Returns the category for the file store.
 
-        :return: The code for the file store.
+        :return: The category for the file store.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def fs_id(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the file store.
+        Returns the label for the file store.
 
-        :return: The ID for the file store.
+        :return: The label for the file store.
         :rtype: str
         """
-        return self._fs_id
+        return self._label
 
     @property
     def client_type(self) -> str:
@@ -821,8 +820,8 @@ class FileStoreMetadataRequest:
         """
         self._api_key = metadata_request.apiKey
         self._source = metadata_request.source
-        self._code = metadata_request.code
-        self._fs_id = metadata_request.id
+        self._category = metadata_request.category
+        self._label = metadata_request.label
         self._client_type = metadata_request.clientType
 
     def _write_proto_object(self) -> FileStoreMetadataRequest_pb2.FileStoreMetadataRequest:
@@ -835,8 +834,8 @@ class FileStoreMetadataRequest:
         request = FileStoreMetadataRequest_pb2.FileStoreMetadataRequest()
         request.apiKey = self._api_key
         request.source = self._source
-        request.code = self._code
-        request.id = self._fs_id
+        request.category = self._category
+        request.label = self._label
         request.clientType = self._client_type
 
         return request
@@ -1021,19 +1020,19 @@ class FileStoreRequest:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 fs_id: str,
+                 category: str,
+                 label: str,
                  name: str,
                  api_key: str = None):
         """
         :param source: The source for the file store.
         :type source: str
 
-        :param code: The code for the file store.
-        :type code: str
+        :param category: The category for the file store.
+        :type category: str
 
-        :param fs_id: The ID of the file.
-        :type fs_id: str
+        :param label: The label for the file store.
+        :type label: str
 
         :param name: The name of the file.
         :type name: str
@@ -1055,17 +1054,17 @@ class FileStoreRequest:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(fs_id, str):
-            raise ValueError("fs_id is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(fs_id):
-            raise ValueError("fs_id is not valid")
+        if not is_valid_token(label):
+            raise ValueError("label is not valid")
 
         if not isinstance(name, str):
             raise ValueError("name is not a valid str")
@@ -1074,8 +1073,8 @@ class FileStoreRequest:
 
         self._api_key = api_key
         self._source = source
-        self._code = code
-        self._fs_id = fs_id
+        self._category = category
+        self._label = label
         self._name = name
         self._client_type = ClientType.PYTHON_CLIENT
 
@@ -1113,24 +1112,24 @@ class FileStoreRequest:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the file store.
+        Returns the category for the file store.
 
-        :return: The code for the file store.
+        :return: The category for the file store.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def fs_id(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the file store.
+        Returns the label for the file store.
 
-        :return: The ID for the file store.
+        :return: The label for the file store.
         :rtype: str
         """
-        return self._fs_id
+        return self._label
 
     @property
     def name(self) -> str:
@@ -1188,8 +1187,8 @@ class FileStoreRequest:
         """
         self._api_key = request.apiKey
         self._source = request.source
-        self._code = request.code
-        self._fs_id = request.id
+        self._category = request.category
+        self._label = request.label
         self._name = request.name
         self._client_type = request.clientType
 
@@ -1203,8 +1202,8 @@ class FileStoreRequest:
         request = FileStoreRequest_pb2.FileStoreRequest()
         request.apiKey = self._api_key
         request.source = self._source
-        request.code = self._code
-        request.id = self._fs_id
+        request.category = self._category
+        request.label = self._label
         request.name = self._name
         request.clientType = self._client_type
 
@@ -1414,8 +1413,8 @@ class FileMetadataRequest:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 fs_id: str,
+                 category: str,
+                 label: str,
                  pattern: str = None,
                  api_key: str = None):
         """
@@ -1424,11 +1423,11 @@ class FileMetadataRequest:
         :param source: The source for the file store.
         :type source: str
 
-        :param code: The code for the file store.
-        :type code: str
+        :param category: The category for the file store.
+        :type category: str
 
-        :param fs_id: The ID for the file store.
-        :type fs_id: str
+        :param label: The label for the file store.
+        :type label: str
 
         :param pattern: The pattern that the name of a file whose metadata is returned should match; None will match all files.
         :type pattern: str
@@ -1450,24 +1449,24 @@ class FileMetadataRequest:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(fs_id, str):
-            raise ValueError("fs_id is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(fs_id):
-            raise ValueError("fs_id is not valid")
+        if not is_valid_token(label):
+            raise ValueError("label is not valid")
 
         # Store the data
 
         self._api_key = api_key
         self._source = source
-        self._code = code
-        self._fs_id = fs_id
+        self._category = category
+        self._label = label
         self._pattern = pattern
         self._client_type = ClientType.PYTHON_CLIENT
 
@@ -1508,24 +1507,24 @@ class FileMetadataRequest:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the file store.
+        Returns the category for the file store.
 
-        :return: The code for the file store.
+        :return: The category for the file store.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def fs_id(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the file store.
+        Returns the label for the file store.
 
-        :return: The ID for the file store.
+        :return: The label for the file store.
         :rtype: str
         """
-        return self._fs_id
+        return self._label
 
     @property
     def pattern(self) -> str:
@@ -1585,8 +1584,8 @@ class FileMetadataRequest:
         """
         self._api_key = metadata_request.apiKey
         self._source = metadata_request.source
-        self._code = metadata_request.code
-        self._fs_id = metadata_request.id
+        self._category = metadata_request.category
+        self._label = metadata_request.label
         self._client_type = metadata_request.clientType
 
         if metadata_request.patternSet:
@@ -1604,8 +1603,8 @@ class FileMetadataRequest:
         request = FileMetadataRequest_pb2.FileMetadataRequest()
         request.apiKey = self._api_key
         request.source = self._source
-        request.code = self._code
-        request.id = self.fs_id
+        request.category = self._category
+        request.label = self._label
 
         if self._pattern is None:
             request.patternSet = False
