@@ -4,15 +4,15 @@ Classes and functions related to time-series.
 from __future__ import annotations
 
 from archipelagos.common.data import get_secs_from_timestamp, get_nanos_from_timestamp, get_timestamp
-from archipelagos.common.data import get_yyyy_mm_dd_hh_mm_ss_n
 from archipelagos.common.protobuf.common.data.timeseries import TimeSeriesMetadata_pb2, TimeSeriesData_pb2
 from archipelagos.common.protobuf.common.data.timeseries import TimeSeriesMetadataRequest_pb2, TimeSeries_pb2
 from archipelagos.common.protobuf.common.data.timeseries import TimeSeriesRequest_pb2, TimeSeriesResponse_pb2
 from archipelagos.common.protobuf.common.data.timeseries import TimeSeriesMetadataResponse_pb2
+from archipelagos.common.data import _get_feature_value, _get_feature_value_from_proto
+from archipelagos.common.data import _valid_feature_value, _feature_value_equals
 from archipelagos.common.protobuf.common.data import DataEntry_pb2
 from archipelagos.common.protobuf.common import Timestamp_pb2
-from archipelagos.common.data import _valid_feature_value, _feature_value_equals
-from archipelagos.common.data import _get_feature_value, _get_feature_value_from_proto
+from archipelagos.common.data import get_yyyy_mm_dd_hh_mm_ss_n
 from archipelagos.common.data import Frequency, is_valid_token
 from archipelagos.common.platform import ClientType
 
@@ -28,8 +28,8 @@ class TimeSeriesMetadata:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 ts_id: str,
+                 category: str,
+                 label: str,
                  url: str,
                  summary: str,
                  description: str,
@@ -48,11 +48,11 @@ class TimeSeriesMetadata:
         :param source: The source for the time-series.
         :type source: str
 
-        :param code: The code for the time-series.
-        :type code: str
+        :param category: The category for the time-series.
+        :type category: str
 
-        :param ts_id: The ID for the time-series.
-        :type ts_id: str
+        :param label: The label for the time-series.
+        :type label: str
 
         :param url: The URL for the time-series.
         :type url:
@@ -98,17 +98,17 @@ class TimeSeriesMetadata:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(ts_id, str):
-            raise ValueError("ts_id is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(ts_id):
-            raise ValueError("ts_id is not valid")
+        if not is_valid_token(label):
+            raise ValueError("label is not valid")
 
         if not isinstance(url, str):
             raise ValueError("url is not a valid str")
@@ -179,8 +179,8 @@ class TimeSeriesMetadata:
         # Store the data
 
         self._source = source
-        self._code = code
-        self._ts_id = ts_id
+        self._category = category
+        self._label = label
         self._url = url
         self._summary = summary
         self._description = description
@@ -204,8 +204,8 @@ class TimeSeriesMetadata:
         result = 1
 
         result = prime * result + hash(self._source) if self._source is not None else 0
-        result = prime * result + hash(self._code) if self._code is not None else 0
-        result = prime * result + hash(self._ts_id) if self._ts_id is not None else 0
+        result = prime * result + hash(self._category) if self._category is not None else 0
+        result = prime * result + hash(self._label) if self._label is not None else 0
 
         self._hash_code = result
 
@@ -220,24 +220,24 @@ class TimeSeriesMetadata:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the time-series.
+        Returns the category for the time-series.
 
-        :return: The code for the time-series.
+        :return: The category for the time-series.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def ts_id(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the time-series.
+        Returns the label for the time-series.
 
-        :return: The ID for the time-series.
+        :return: The label for the time-series.
         :rtype: str
         """
-        return self._ts_id
+        return self._label
 
     @property
     def url(self) -> str:
@@ -397,8 +397,8 @@ class TimeSeriesMetadata:
         :type metadata: TimeSeriesMetadata_pb2.TimeSeriesMetadata
         """
         self._source = metadata.source
-        self._code = metadata.code
-        self._ts_id = metadata.id
+        self._category = metadata.category
+        self._label = metadata.label
         self._url = metadata.url
         self._summary = metadata.summary
         self._description = metadata.description
@@ -448,8 +448,8 @@ class TimeSeriesMetadata:
         """
         metadata = TimeSeriesMetadata_pb2.TimeSeriesMetadata()
         metadata.source = self._source
-        metadata.code = self._code
-        metadata.id = self._ts_id
+        metadata.category = self._category
+        metadata.label = self._label
         metadata.url = self._url
         metadata.summary = self._summary
         metadata.description = self._description
@@ -516,14 +516,14 @@ class TimeSeriesMetadata:
             elif self._source != other._source:
                 return False
 
-            if self._code is None and other._code is not None:
+            if self._category is None and other._category is not None:
                 return False
-            elif self._code != other._code:
+            elif self._category != other._category:
                 return False
 
-            if self._ts_id is None and other._ts_id is not None:
+            if self._label is None and other._label is not None:
                 return False
-            elif self._ts_id != other._ts_id:
+            elif self._label != other._label:
                 return False
 
             return True
@@ -535,8 +535,8 @@ class TimeSeriesMetadata:
 
     def __str__(self):
         return "Source = " + self._source + \
-               "Code = " + self._code + \
-               "ID = " + self._ts_id + \
+               "Category = " + self._category + \
+               "Label = " + self._label + \
                "URL = " + self._url + \
                "Summary = " + self._summary + \
                "Description = " + self._description + \
@@ -958,8 +958,8 @@ class TimeSeriesMetadataRequest:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 ts_id: str,
+                 category: str,
+                 label: str,
                  api_key: str = None):
         """
         All parameters should be supplied unless deserializing an object.
@@ -967,11 +967,11 @@ class TimeSeriesMetadataRequest:
         :param source: The source for the time-series.
         :type source: str
 
-        :param code: The code for the time-series.
-        :type code: str
+        :param category: The category for the time-series.
+        :type category: str
 
-        :param ts_id: The ID for the time-series.
-        :type ts_id: str
+        :param label: The label for the time-series.
+        :type label: str
 
         :param api_key: The API Key.
         :type api_key: str or None
@@ -990,24 +990,24 @@ class TimeSeriesMetadataRequest:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(ts_id, str):
-            raise ValueError("ts_id is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(ts_id):
-            raise ValueError("ts_id is not valid")
+        if not is_valid_token(label):
+            raise ValueError("label is not valid")
 
         # Store the data
 
         self._api_key = api_key
         self._source = source
-        self._code = code
-        self._ts_id = ts_id
+        self._category = category
+        self._label = label
         self._client_type = ClientType.PYTHON_CLIENT
 
     @property
@@ -1047,24 +1047,24 @@ class TimeSeriesMetadataRequest:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the time-series.
+        Returns the category for the time-series.
 
-        :return: The code for the time-series.
+        :return: The category for the time-series.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def ts_id(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the time-series.
+        Returns the label for the time-series.
 
-        :return: The ID for the time-series.
+        :return: The label for the time-series.
         :rtype: str
         """
-        return self._ts_id
+        return self._label
 
     @property
     def client_type(self) -> str:
@@ -1112,8 +1112,8 @@ class TimeSeriesMetadataRequest:
         """
         self._api_key = metadata_request.apiKey
         self._source = metadata_request.source
-        self._code = metadata_request.code
-        self._ts_id = metadata_request.id
+        self._category = metadata_request.category
+        self._label = metadata_request.label
         self._client_type = metadata_request.clientType
 
     def _write_proto_object(self) -> TimeSeriesMetadataRequest_pb2.TimeSeriesMetadataRequest:
@@ -1126,8 +1126,8 @@ class TimeSeriesMetadataRequest:
         request = TimeSeriesMetadataRequest_pb2.TimeSeriesMetadataRequest()
         request.apiKey = self._api_key
         request.source = self._source
-        request.code = self._code
-        request.id = self._ts_id
+        request.category = self._category
+        request.label = self._label
         request.clientType = self._client_type
 
         return request
@@ -1312,8 +1312,8 @@ class TimeSeriesRequest:
     """
     def __init__(self,
                  source: str,
-                 code: str,
-                 ts_id: str,
+                 category: str,
+                 label: str,
                  start: Timestamp = None,
                  end: Timestamp = None,
                  features: List[str] = None,
@@ -1325,11 +1325,11 @@ class TimeSeriesRequest:
         :param source: The source for the time-series.
         :type source: str
 
-        :param code: The code for the time-series.
-        :type code: str
+        :param category: The category for the time-series.
+        :type category: str
 
-        :param ts_id: The ID for the time-series.
-        :type ts_id: str
+        :param label: The label for the time-series.
+        :type label: str
 
         :param start: The (optional) start date/time, or None.
         :type start: Timestamp
@@ -1366,17 +1366,17 @@ class TimeSeriesRequest:
         if not is_valid_token(source):
             raise ValueError("source is not valid")
 
-        if not isinstance(code, str):
-            raise ValueError("code is not a valid str")
+        if not isinstance(category, str):
+            raise ValueError("category is not a valid str")
 
-        if not is_valid_token(code):
-            raise ValueError("code is not valid")
+        if not is_valid_token(category):
+            raise ValueError("category is not valid")
 
-        if not isinstance(ts_id, str):
-            raise ValueError("ts_id is not a valid str")
+        if not isinstance(label, str):
+            raise ValueError("label is not a valid str")
 
-        if not is_valid_token(ts_id):
-            raise ValueError("ts_id is not valid")
+        if not is_valid_token(label):
+            raise ValueError("label is not valid")
 
         if start is not None:
             if not isinstance(start, Timestamp):
@@ -1423,8 +1423,8 @@ class TimeSeriesRequest:
 
         self._api_key = api_key
         self._source = source
-        self._code = code
-        self._ts_id = ts_id
+        self._category = category
+        self._label = label
         self._start = start
         self._end = end
         self._features = features
@@ -1467,24 +1467,24 @@ class TimeSeriesRequest:
         return self._source
 
     @property
-    def code(self) -> str:
+    def category(self) -> str:
         """
-        Returns the code for the time-series.
+        Returns the category for the time-series.
 
-        :return: The code for the time-series.
+        :return: The category for the time-series.
         :rtype: str
         """
-        return self._code
+        return self._category
 
     @property
-    def ts_id(self) -> str:
+    def label(self) -> str:
         """
-        Returns the ID for the time-series.
+        Returns the label for the time-series.
 
-        :return: The ID for the time-series.
+        :return: The label for the time-series.
         :rtype: str
         """
-        return self._ts_id
+        return self._label
 
     @property
     def start(self) -> Timestamp or None:
@@ -1609,8 +1609,8 @@ class TimeSeriesRequest:
         """
         self._api_key = request.apiKey
         self._source = request.source
-        self._code = request.code
-        self._ts_id = request.id
+        self._category = request.category
+        self._label = request.label
 
         if request.startSet:
             self._start = TimeSeriesRequest._get_datetime(request.start)
@@ -1649,8 +1649,8 @@ class TimeSeriesRequest:
         request = TimeSeriesRequest_pb2.TimeSeriesRequest()
         request.apiKey = self._api_key
         request.source = self._source
-        request.code = self._code
-        request.id = self.ts_id
+        request.category = self._category
+        request.label = self.label
 
         if self._start is None:
             request.startSet = False
